@@ -62,47 +62,49 @@ NMixRelabel.GLMM_MCMC <- function(object, type=c("mean", "weight", "stephens"),
   l_nchange <- ifelse(RAlg$Ctype <= 2, 1, RAlg$relabel$par$maxiter)
   
   MCMC <- .C("GLMM_NMixRelabel",
-             type         = as.integer(RAlg$Ctype),
-             iparam       = as.integer(RAlg$iparam),
-             Y_c          = as.double(object$Cpar$Y_c),
-             Y_d          = as.integer(object$Cpar$Y_d),
-             R_cd         = as.integer(object$Cpar$R_cd),
-             dist         = as.integer(object$Cpar$dist),
-             I            = as.integer(object$Cpar$I),
-             n            = as.integer(object$Cpar$n),
-             X            = as.double(object$Cpar$X),
-             Z            = as.double(object$Cpar$Z),
-             p_fI_q_rI    = as.integer(object$Cpar$p_fI_q_rI),
-             shiftScale_b = as.double(c(object$scale.b$shift, object$scale.b$scale)),
-             keepMCMC     = as.integer(keepMCMC),
-             info         = as.integer(info),
-             tune_scale_b = as.double(object$Cpar$tune_scale_b),
-             chsigma_eps  = if (object$R["Rc"]) as.double(t(object$sigma_eps)) else as.double(0),
-             K_b          = as.integer(object$K_b[1]),
-             chw_b        = as.double(t(object$w_b)),
-             chmu_b       = as.double(t(object$mu_b)),
-             chQ_b        = as.double(t(object$Q_b)),
-             chSigma_b    = as.double(t(object$Sigma_b)),
-             chLi_b       = as.double(t(object$Li_b)),
-             chalpha      = if (l_alpha) as.double(t(object$alpha)) else as.double(0),
-             chorder_b    = integer(object$K_b[1] * keepMCMC),
-             chrank_b     = integer(object$K_b[1] * keepMCMC),
-             b            = as.double(t(object$state.first.b$b)),
-             r_b          = integer(object$Cpar$I),
-             naccept_b    = integer(object$Cpar$I),
-             pm_w_b       = double(object$K_b[1]),
-             pm_mu_b      = double(object$dimb * object$K_b[1]),
-             pm_Q_b       = double(LTp * object$K_b[1]),
-             pm_Sigma_b   = double(LTp * object$K_b[1]),
-             pm_Li_b      = double(LTp * object$K_b[1]),
-             sum_Ir_b     = integer(object$Cpar$I * object$K_b[1]),
-             hatPr_b_b    = double(object$Cpar$I * object$K_b[1]),
-             Pr_b_b       = double(lPr_b),
-             hatPr_obs    = double(object$Cpar$I * object$K_b[1]),
-             Pr_obs       = double(lPr_b),             
-             iter_relabel = as.integer(0),
-             nchange      = integer(l_nchange),
-             err          = as.integer(0),
+             type           = as.integer(RAlg$Ctype),
+             iparam         = as.integer(RAlg$iparam),
+             Y_c            = as.double(object$Cpar$Y_c),
+             Y_d            = as.integer(object$Cpar$Y_d),
+             R_cd           = as.integer(object$Cpar$R_cd),
+             dist           = as.integer(object$Cpar$dist),
+             I              = as.integer(object$Cpar$I),
+             n              = as.integer(object$Cpar$n),
+             X              = as.double(object$Cpar$X),
+             Z              = as.double(object$Cpar$Z),
+             p_fI_q_rI      = as.integer(object$Cpar$p_fI_q_rI),
+             shiftScale_b   = as.double(c(object$scale.b$shift, object$scale.b$scale)),
+             keepMCMC       = as.integer(keepMCMC),
+             info           = as.integer(info),
+             tune_scale_b   = as.double(object$Cpar$tune_scale_b),
+             chsigma_eps    = if (object$R["Rc"]) as.double(t(object$sigma_eps)) else as.double(0),
+             distribution_b = as.integer(object$Cpar$priorInt_b["distribution"]),
+             K_b            = as.integer(object$K_b[1]),
+             chw_b          = as.double(t(object$w_b)),
+             chmu_b         = as.double(t(object$mu_b)),
+             chQ_b          = as.double(t(object$Q_b)),
+             chSigma_b      = as.double(t(object$Sigma_b)),
+             chLi_b         = as.double(t(object$Li_b)),
+             chdf_b         = if (object$Cpar$priorInt_b["distribution"] == 1) as.double(t(object$df_b)) else as.double(0),
+             chalpha        = if (l_alpha) as.double(t(object$alpha)) else as.double(0),             
+             chorder_b      = integer(object$K_b[1] * keepMCMC),
+             chrank_b       = integer(object$K_b[1] * keepMCMC),
+             b              = as.double(t(object$state.first.b$b)),
+             r_b            = integer(object$Cpar$I),
+             naccept_b      = integer(object$Cpar$I),
+             pm_w_b         = double(object$K_b[1]),
+             pm_mu_b        = double(object$dimb * object$K_b[1]),
+             pm_Q_b         = double(LTp * object$K_b[1]),
+             pm_Sigma_b     = double(LTp * object$K_b[1]),
+             pm_Li_b        = double(LTp * object$K_b[1]),
+             sum_Ir_b       = integer(object$Cpar$I * object$K_b[1]),
+             hatPr_b_b      = double(object$Cpar$I * object$K_b[1]),
+             Pr_b_b         = double(lPr_b),
+             hatPr_obs      = double(object$Cpar$I * object$K_b[1]),
+             Pr_obs         = double(lPr_b),             
+             iter_relabel   = as.integer(0),
+             nchange        = integer(l_nchange),
+             err            = as.integer(0),
              PACKAGE = thispackage)
   if (MCMC$err) stop("Something went wrong.")             
 
